﻿# Login to Azure subscription
Login-AzureRmAccount
#$SubscriptionId = (Get-AzureRmSubscription | Out-GridView -Title "Select an Azure Subscription …" -PassThru).SubscriptionId
$SubscriptionId = "97092d11-3522-489f-bcaf-90fbfbc6bea1"
Select-AzureRmSubscription -SubscriptionId $SubscriptionId



# Deploy Resource Group

$RGName = "ntk2017-rg-live"
$Location = "North Europe"

New-AzureRmResourceGroup -Name $RGName -Location $Location

#region Deploy Networking
# Deploy Tier0 VNet
$VNetCoreName = "ntk2017-live-vnet-tier0"
$AddressPrefix = "10.100.10.0/24"
$SubNetCoreName = $VNetCoreName + "-core"
$SubNetCorePrefix = "10.100.10.0/25" #This is for the "Core" subnet
$SubNetFwallExtName = $VNetCoreName + "-fwext"
$SubNetFwallExtPrefix = "10.100.10.160/27" #This is for the "Firewall External" subnet
$SubNetFwallIntName = $VNetCoreName + "-fwint"
$SubNetFwallIntPrefix = "10.100.10.192/27" #This is for the "Firewall Internal" subnet
$GatewaySubnetName = "GatewaySubnet"
$GatewaySubnetPrefix = "10.100.10.128/27" #This is for the "Gateway" subnet
$DnsServers = "10.100.10.4","10.100.10.5"

#Creating Core VNet
New-AzureRmVirtualNetwork -Name $VNetCoreName -ResourceGroupName $RGName -Location $Location -AddressPrefix $AddressPrefix
$VNetCore = Get-AzureRmVirtualNetwork -ResourceGroupName $RGName -Name $VNetCoreName

#Configure DNS settings at VNET level
$VNetCore.DhcpOptions.DnsServers = $DnsServers
#Set-AzureRmVirtualNetwork -VirtualNetwork $VNetCore

#Creating Subnets
Add-AzureRmVirtualNetworkSubnetConfig -Name $SubNetCoreName -VirtualNetwork $VNetCore -AddressPrefix $SubNetCorePrefix
Add-AzureRmVirtualNetworkSubnetConfig -Name $SubNetFwallExtName -VirtualNetwork $VNetCore -AddressPrefix $SubNetFwallExtPrefix
Add-AzureRmVirtualNetworkSubnetConfig -Name $SubNetFwallIntName -VirtualNetwork $VNetCore -AddressPrefix $SubNetFwallIntPrefix
Add-AzureRmVirtualNetworkSubnetConfig -Name $GatewaySubnetName -VirtualNetwork $VNetCore -AddressPrefix $GatewaySubnetPrefix 
Set-AzureRmVirtualNetwork -VirtualNetwork $VNetCore

# Deploy Workload A VNet
$VNetWrkloadAName = "ntk2017-live-vnet-workloada"
$AddressPrefix = "10.100.11.0/24"
$SubNetFrontEndName = $VNetWrkloadAName + "-frontend"
$SubNetFrontEndPrefix = "10.100.11.0/25" #This is for the FrontEnd subnet
$SubNetBackEndName = $VNetWrkloadAName + "-backend"
$SubNetBackEndPrefix = "10.100.11.128/25" #This is for the BackEnd subnet
$DnsServers = "10.100.10.4","10.100.10.5"

#Creating Core VNet
New-AzureRmVirtualNetwork -Name $VNetWrkloadAName -ResourceGroupName $RGName -Location $Location -AddressPrefix $AddressPrefix
$VNetWorkloadA = Get-AzureRmVirtualNetwork -ResourceGroupName $RGName -Name $VNetWrkloadAName

#Configure DNS settings at VNET level
$VNetWorkloadA.DhcpOptions.DnsServers = $DnsServers
#Set-AzureRmVirtualNetwork -VirtualNetwork $VNetWorkloadA

#Creating Subnets
Add-AzureRmVirtualNetworkSubnetConfig -Name $SubNetFrontEndName -VirtualNetwork $VNetWorkloadA -AddressPrefix $SubNetFrontEndPrefix
Add-AzureRmVirtualNetworkSubnetConfig -Name $SubNetBackEndName -VirtualNetwork $VNetWorkloadA -AddressPrefix $SubNetBackEndPrefix
Set-AzureRmVirtualNetwork -VirtualNetwork $VNetWorkloadA

# Create VNet Peerings
Add-AzureRmVirtualNetworkPeering -Name "$VNetCoreName-$VNetWrkloadAName-peering" -VirtualNetwork $VNetCore -RemoteVirtualNetworkId $VNetWorkloadA.Id -AllowForwardedTraffic -AllowGatewayTransit
Add-AzureRmVirtualNetworkPeering -Name "$VNetWrkloadAName-$VNetCoreName-peering" -VirtualNetwork $VNetWorkloadA -RemoteVirtualNetworkId $VNetCore.Id -AllowForwardedTraffic #-UseRemoteGateways

$VNetCore = Get-AzureRmVirtualNetwork -ResourceGroupName $RGName -Name $VNetCoreName
$VNetWorkloadA = Get-AzureRmVirtualNetwork -ResourceGroupName $RGName -Name $VNetWrkloadAName

# Network Security Groups
# Define allow rule for RDP from Internet
$nsgName = "ntk2017-live-nsg-blockinetallowrdp"
$rules = @()

$BlockInetrule =     New-AzureRmNetworkSecurityRuleConfig `
		-Name "ntk2017live-nsgrule-oba-virtualnetwork-all-internet" `
		-Description "Block access to internet" `
		-Access Deny `
		-Protocol * `
		-Direction Outbound `
		-Priority 3999 `
		-SourceAddressPrefix VirtualNetwork `
		-SourcePortRange * `
		-DestinationAddressPrefix Internet `
		-DestinationPortRange *

$rules += $BlockInetrule

$RDPInRule =     New-AzureRmNetworkSecurityRuleConfig `
		-Name "ntk2017live-nsgrule-iba-internet-RDP-virtualnetwork" `
		-Description "Allow RDP traffic from internet" `
		-Access Allow `
		-Protocol TCP `
		-Direction Inbound `
		-Priority 1000 `
		-SourceAddressPrefix Internet `
		-SourcePortRange * `
		-DestinationAddressPrefix VirtualNetwork `
		-DestinationPortRange 3389

$rules += $RDPInRule

$RDPOutRule =     New-AzureRmNetworkSecurityRuleConfig `
		-Name "ntk2017live-nsgrule-oba-virtualnetwork-RDP-internet" `
		-Description "Allow RDP traffic from internet" `
		-Access Allow `
		-Protocol TCP `
		-Direction Outbound `
		-Priority 1100 `
		-SourceAddressPrefix VirtualNetwork `
		-SourcePortRange 3389 `
		-DestinationAddressPrefix Internet `
		-DestinationPortRange *

$rules += $RDPOutRule

$nsg = New-AzureRmNetworkSecurityGroup `
       -Name $nsgName `
       -ResourceGroupName $rgName `
       -Location $location `
       -SecurityRules $rules

#endregion

#region DC1
# VMs
#Install-Module AzureRM.Compute -RequiredVersion 2.6.0
$cred = Get-Credential

$vmNameDC1 = "avmdc1-nt17live"
$computerNameDC1 = $vmNameDC1
$vmSize = "Standard_DS1_v2"
$DCAvailabilitySetName = "asdc-nt17-live"
$DC1PrivateIpAddress = "10.100.10.4"
$DC1NicName = $vmNameDC1 + "-nic0"


# Create Availability Set, Public IP and Nic
$DCAvailabilitySet = New-AzureRmAvailabilitySet -ResourceGroupName $RGName -Name $DCAvailabilitySetName -Location $Location -Managed -PlatformFaultDomainCount 3 -PlatformUpdateDomainCount 5
$pipDC1 = New-AzureRmPublicIpAddress -Name "$DC1NicName-pip" -ResourceGroupName $rgName -Location $location -AllocationMethod Dynamic
$nicDC1 = New-AzureRmNetworkInterface -Name $DC1NicName -ResourceGroupName $RGName -Location $Location -SubnetId (Get-AzureRmVirtualNetworkSubnetConfig -VirtualNetwork $VNetCore -Name $SubNetCoreName).Id -PrivateIpAddress $DC1PrivateIpAddress -PublicIpAddressId $pipDC1.id

$vmDC1 = New-AzureRmVMConfig -VMName $vmNameDC1 -VMSize $vmSize -AvailabilitySetId $DCAvailabilitySet.Id

#Set the VM image as source image for the new VM
$vmDC1 = Set-AzureRmVMSourceImage -VM $vmDC1 -PublisherName "MicrosoftWindowsServer" -Offer "WindowsServer" -Skus "2016-Datacenter" -Version "latest"

#Set the OS configuration and add the NIC
$vmDC1 = Set-AzureRmVMOSDisk -VM $vmDC1 -StorageAccountType StandardLRS  -DiskSizeInGB 128 -Caching ReadWrite -CreateOption FromImage
$vmDC1 = Set-AzureRmVMOperatingSystem -VM $vmDC1 -Windows -ComputerName $computerNameDC1 -Credential $cred -ProvisionVMAgent -EnableAutoUpdate
$vmDC1 = Add-AzureRmVMNetworkInterface -VM $vmDC1 -Id $nicDC1.Id

#Create the VM
New-AzureRmVM -VM $vmDC1 -ResourceGroupName $rgName -Location $location 
#endregion

#region FE1
$VNetWorkloadA = Get-AzureRmVirtualNetwork -ResourceGroupName $RGName -Name $VNetWrkloadAName
$vmNameFE1 = "avmfe1-nt17-l1x"
$computerNameFE1 = $vmNameFE1
$vmSize = "Standard_DS1_v2"
$FEAvailabilitySetName = "asfe-nt17-l1x"
$FE1PrivateIpAddress = "10.100.11.10"
$FE1NicName = $vmNameFE1 + "-nic0"


# Create Availability Set, Public IP and Nic
$FEAvailabilitySet = New-AzureRmAvailabilitySet -ResourceGroupName $RGName -Name $FEAvailabilitySetName -Location $Location -Managed -PlatformFaultDomainCount 3 -PlatformUpdateDomainCount 5
$pipFE1 = New-AzureRmPublicIpAddress -Name "$FE1NicName-pip" -ResourceGroupName $rgName -Location $location -AllocationMethod Dynamic
$nicFE1 = New-AzureRmNetworkInterface -Name $FE1NicName -ResourceGroupName $RGName -Location $Location -SubnetId (Get-AzureRmVirtualNetworkSubnetConfig -VirtualNetwork $VNetWorkloadA -Name $SubNetFrontEndName).Id -PrivateIpAddress $FE1PrivateIpAddress -PublicIpAddressId $pipFE1.id

$vmFE1 = New-AzureRmVMConfig -VMName $vmNameFE1 -VMSize $vmSize -AvailabilitySetId $FEAvailabilitySet.Id

#Set the VM image as source image for the new VM
$vmFE1 = Set-AzureRmVMSourceImage -VM $vmFE1 -PublisherName "MicrosoftWindowsServer" -Offer "WindowsServer" -Skus "2016-Datacenter" -Version "latest"

#Set the OS configuration and add the NIC
$vmFE1 = Set-AzureRmVMOSDisk -VM $vmFE1 -StorageAccountType StandardLRS  -DiskSizeInGB 128 -Caching ReadWrite -CreateOption FromImage
$vmFE1 = Set-AzureRmVMOperatingSystem -VM $vmFE1 -Windows -ComputerName $computerNameFE1 -Credential $cred -ProvisionVMAgent -EnableAutoUpdate
$vmFE1 = Add-AzureRmVMNetworkInterface -VM $vmFE1 -Id $nicFE1.Id

#Create the VM
New-AzureRmVM -VM $vmFE1 -ResourceGroupName $rgName -Location $location 
#endregion


#region BE1
$vmNameBE1 = "avmbe1-nt17-l1x"
$computerNameBE1 = $vmNameBE1
$vmSize = "Standard_DS1_v2"
$BEAvailabilitySetName = "asbe-nt17-l1x"
$BE1PrivateIpAddress = "10.100.11.140"
$BE1NicName = $vmNameBE1 + "-nic0"


# Create Availability Set, Public IP and Nic
$BEAvailabilitySet = New-AzureRmAvailabilitySet -ResourceGroupName $RGName -Name $BEAvailabilitySetName -Location $Location -Managed -PlatformFaultDomainCount 3 -PlatformUpdateDomainCount 5
$pipBE1 = New-AzureRmPublicIpAddress -Name "$BE1NicName-pip" -ResourceGroupName $rgName -Location $location -AllocationMethod Dynamic
$nicBE1 = New-AzureRmNetworkInterface -Name $BE1NicName -ResourceGroupName $RGName -Location $Location -SubnetId (Get-AzureRmVirtualNetworkSubnetConfig -VirtualNetwork $VNetWorkloadA -Name $SubNetBackEndName).Id -PrivateIpAddress $BE1PrivateIpAddress -PublicIpAddressId $pipBE1.id

$vmBE1 = New-AzureRmVMConfig -VMName $vmNameBE1 -VMSize $vmSize -AvailabilitySetId $BEAvailabilitySet.Id

#Set the VM image as source image for the new VM
$vmBE1 = Set-AzureRmVMSourceImage -VM $vmBE1 -PublisherName "MicrosoftSQLServer" -Offer "SQL2016SP1-WS2016" -Skus "Standard" -Version "latest"

#Set the OS configuration and add the NIC
$vmBE1 = Set-AzureRmVMOSDisk -VM $vmBE1 -StorageAccountType StandardLRS  -DiskSizeInGB 128 -Caching ReadWrite -CreateOption FromImage
$vmBE1 = Add-AzureRmVMDataDisk -VM $vmBE1 -StorageAccountType StandardLRS  -DiskSizeInGB 256 -Caching None -Lun 0 -CreateOption Empty
$vmBE1 = Set-AzureRmVMOperatingSystem -VM $vmBE1 -Windows -ComputerName $computerNameBE1 -Credential $cred -ProvisionVMAgent -EnableAutoUpdate
$vmBE1 = Add-AzureRmVMNetworkInterface -VM $vmBE1 -Id $nicBE1.Id

#Create the VM
New-AzureRmVM -VM $vmBE1 -ResourceGroupName $rgName -Location $location 
#endregion














#Get-AzureRmVMImageOffer -Location $Location -PublisherName "MicrosoftWindowsServer" 
#Get-AzureRmVMImageSku -Location $Location -PublisherName "MicrosoftWindowsServer" -Offer "WindowsServer"
$image = Get-AzureRmVMImage -Location $Location -PublisherName "MicrosoftSQLServer" -Offer "SQL2016SP1-WS2016-BYOL" -Skus "Standard" -Version "latest"

$diskconfig = New-AzureRmDiskConfig -Location $Location -DiskSizeGB 50 -AccountType StandardLRS -OsType Windows -CreateOption FromImage -EncryptionSettingsEnabled $true -ImageReference $image
New-AzureRmDisk -ResourceGroupName $RGName -DiskName 'Disk01' -Disk $diskconfig 






# Deploy 
FE1
BE2

# Portal - deploy CheckPoint

# Depoloy
DC2 - ARM 


# Additional NSGs
# Routing


DC1
DC2
FE1
BE1

# CheckPoint


# Routing?

Get-AzureRmVMImageOffer -Location $Location -PublisherName "Microsoft.Compute"

Get-AzureRmVMImagePublisher -Location $Location

#Get-AzureRmVMUsage -Location $Location